@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from pathlib import Path
-from collections import Iterable
+from collections.abc import Iterable
 import xml.etree.ElementTree as ET
 import json
 
@@ -55,18 +55,19 @@ def event_reader(filepath, types=None):
 def _event_reader_xml(filepath):
     """ Any content text of the XML element itself is dropped, as MATSim events are attribute-only. """
     with xopen(filepath) as f:
-        tree = ET.iterparse(f)
+        tree = ET.iterparse(f, events=['start', 'end'])
+        _, root = next(tree)
         try:
             for xml_event, elem in tree:
                 attributes = elem.attrib
 
-                if elem.tag == 'event':
+                if xml_event == 'start' and elem.tag == 'event':
                     # got one! yield the event to the caller
                     attributes['time'] = float(attributes['time'])
                     yield attributes
 
                 # free memory. Otherwise the data is kept in memory and we loose the advantage of streaming
-                elem.clear()
+                root.clear()
 
         except Exception as e:
             # Why am I catching this exception instead of allowing it to propagate up?
@@ -112,5 +113,5 @@ def _convert_pb_event(event):
 
 def _event_reader_json(filepath):
     with xopen(filepath) as f:
-        for line in f.readlines():
+        for line in f:
             yield json.loads(line)
